==> spip_3.0.18.orig.tar.xz: spip/plugins-dist/dump/lang/dump_oc_ni_mis.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/dump?lang_cible=oc_ni_mis
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'aucune_donnee' => 'vuèi',
	'avis_probleme_ecriture_fichier' => 'Proublèma d’escritura dóu fichié @fichier@',

	// B
	'bouton_restaurer_base' => 'Restaurà la basa',

	// C
	'confirmer_ecraser_base' => 'Ahì, vouòli escrasà la miéu basa embé aquela sauvagarda',
	'confirmer_ecraser_tables_selection' => 'Ahì, vouòli escrasà li taula seleciounadi embé aquela sauvagarda',
	'confirmer_supprimer_sauvegarde' => 'Sias segur de voulé suprimà aquela sauvagarda ?',

	// D
	'details_sauvegarde' => 'Detai de la sauvagarda :',

	// E
	'erreur_aucune_donnee_restauree' => 'Minga dounada restaurada',
	'erreur_connect_dump' => 'Esista jà un servidou nouminat « @dump@ ». Renouminàs-lou.',
	'erreur_creation_base_sqlite' => 'Empoussible de creà una basa SQLite per la sauvagarda',
	'erreur_nom_fichier' => 'Aqueu noum de fichié es pas autourisat',
	'erreur_restaurer_verifiez' => 'Courregès l’errour per poudé restaurà.',
	'erreur_sauvegarde_deja_en_cours' => 'Avès jà una sauvagarda en cours',
	'erreur_sqlite_indisponible' => 'Empoussible de faire una sauvagarda SQLite sus lou vouòstre aubergadour',
	'erreur_table_absente' => 'Taula @table@ assenta',
	'erreur_table_donnees_manquantes' => 'Taula @table@, dounada mancanti',
	'erreur_taille_sauvegarde' => 'La sauvagarda a souhit. Lou fichié @fichier@ es viéu o assent.',

	// I
	'info_aucune_sauvegarde_trouvee' => 'Minga sauvagarda troubada',
	'info_restauration_finie' => 'Es acabat ! La sauvagarda @archive@ es estada restaurada en lou vouòstre sit. Poudès',
	'info_restauration_sauvegarde' => 'Restauracioun de la sauvagarda @archive@',
	'info_sauvegarde' => 'Sauvagarda',
	'info_sauvegarde_reussi_02' => 'La basa es estada sauvagardada en @archive@. Poudès',
	'info_sauvegarde_reussi_03' => 'tournà à la gestioun',
	'info_sauvegarde_reussi_04' => 'dóu vouòstre sit.',
	'info_selection_sauvegarde' => 'Avès chausit de restaurà la sauvagarda @fichier@. Aquela ouperacioun noun es reversìble.',

	// L
	'label_nom_fichier_restaurer' => 'O indàs lou noum dóu fichié da restaurà',
	'label_nom_fichier_sauvegarde' => 'Noum dóu fichié da la sauvegarde',
	'label_selectionnez_fichier' => 'Seleciounàs un fichié en la lista',

	// N
	'nb_donnees' => '@nb@ enregistramen',

	// R
	'restauration_en_cours' => 'Restauracioun en cours',

	// S
	'sauvegarde_en_cours' => 'Sauvagarda en cours',
	'sauvegardes_existantes' => 'Sauvagarda esistenti',
	'selectionnez_table_a_restaurer' => 'Seleciounàs li taula da restaurà',

	// T
	'texte_admin_tech_01' => 'Aquela oupcioun vous permete de sauvagardà lou countengut de la basa en un fichier que serà counservat en lou repertori @dossier@. Noun oublidès màncou de recuperà l’integralità dóu repertori @img@, que counten lu image e lu doucumen utilisat en lu article e rùbrica.',
	'texte_admin_tech_02' => 'Mèfi : aquela sauvagarda si pourà estre restaurada SOULAMEN en un sit instalat embé la mema versioun de SPIP. Cau soubretout pas « vuà la basa » en esperant reinstalà la sauvagarda après una metuda a jou... Cousultàs la <a href="@spipnet@">la doucumentacioun de SPIP</a>.',
	'texte_restaurer_base' => 'Restaurà lou countengut d’una sauvagarda de la basa',
	'texte_restaurer_sauvegarde' => 'Aquela oupcioun vous permete de restaurà una sauvagarda prechedenta de la
 basa. Per faire acò, cau avé plaçat lou fichié que counten
 la sauvagarda en lou repertori @dossier@.
  Siguès prudent embé aquela founciounalità : <b>li moudificacioun e li perta eventuali noun soun
  reversibli.</b>',
	'texte_sauvegarde' => 'Sauvagardà lou countengut de la basa',
	'texte_sauvegarde_base' => 'Sauvagardà la basa',
	'tout_restaurer' => 'Restaurà touti li taula',
	'tout_sauvegarder' => 'Sauvagardà touti li taula',

	// U
	'une_donnee' => '1 enregistramen'
);

?>

==> spip_3.1.4.orig.tar.xz: spip/plugins-dist/dump/lang/dump_oc_ni_mis.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/dump?lang_cible=oc_ni_mis
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'aucune_donnee' => 'vuèi',
	'avis_probleme_ecriture_fichier' => 'Proublèma d’escritura dóu fichié @fichier@',

	// B
	'bouton_restaurer_base' => 'Restaurà la basa',

	// C
	'confirmer_ecraser_base' => 'Ahì, vouòli escrasà la miéu basa embé aquela sauvagarda',
	'confirmer_ecraser_tables_selection' => 'Ahì, vouòli escrasà li taula seleciounadi embé aquela sauvagarda',
	'confirmer_supprimer_sauvegarde' => 'Sias segur de voulé suprimà aquela sauvagarda ?',

	// D
	'details_sauvegarde' => 'Detai de la sauvagarda :',

	// E
	'erreur_aucune_donnee_restauree' => 'Minga dounada restaurada',
	'erreur_connect_dump' => 'Esista jà un servidou nouminat « @dump@ ». Renouminàs-lou.',
	'erreur_creation_base_sqlite' => 'Empoussible de creà una basa SQLite per la sauvagarda',
	'erreur_nom_fichier' => 'Aqueu noum de fichié es pas autourisat',
	'erreur_restaurer_verifiez' => 'Courregès l’errour per poudé restaurà.',
	'erreur_sauvegarde_deja_en_cours' => 'Avès jà una sauvagarda en cours',
	'erreur_sqlite_indisponible' => 'Empoussible de faire una sauvagarda SQLite sus lou vouòstre aubergadour',
	'erreur_table_absente' => 'Taula @table@ assenta',
	'erreur_table_donnees_manquantes' => 'Taula @table@, dounada mancanti',
	'erreur_taille_sauvegarde' => 'La sauvagarda a souhit. Lou fichié @fichier@ es viéu o assent.',

	// I
	'info_aucune_sauvegarde_trouvee' => 'Minga sauvagarda trouvada',
	'info_restauration_finie' => 'Es acabat ! La sauvagarda @archive@ es estada restaurada en lou vouòstre sit. Poudès',
	'info_restauration_sauvegarde' => 'Restauracioun de la sauvagarda @archive@',
	'info_sauvegarde' => 'Sauvagarda',
	'info_sauvegarde_reussi_02' => 'La basa es estada sauvagardada en @archive@. Poudès',
	'info_sauvegarde_reussi_03' => 'tournà à la gestioun',
	'info_sauvegarde_reussi_04' => 'dóu vouòstre sit.',
	'info_selection_sauvegarde' => 'Avès chausit de restaurà la sauvagarda @fichier@. Aquela ouperacioun noun es reversìble.',

	// L
	'label_nom_fichier_restaurer' => 'O indàs lou noum dóu fichié da restaurà',
	'label_nom_fichier_sauvegarde' => 'Noum dóu fichié per la sauvegarde',
	'label_selectionnez_fichier' => 'Seleciounàs un fichié en la lista',

	// N
	'nb_donnees' => '@nb@ enregistramen',

	// R
	'restauration_en_cours' => 'Restauracioun en cours',

	// S
	'sauvegarde_en_cours' => 'Sauvagarda en cours',
	'sauvegardes_existantes' => 'Sauvagarda esistenti',
	'selectionnez_table_a_restaurer' => 'Seleciounàs li taula da restaurà',

	// T
	'texte_admin_tech_01' => 'Aquela oupcioun vous permete de sauvagardà lou countengut de la basa en un fichier que serà counservat en lou repertori @dossier@. Noun oublidès màncou de recuperà l’integralità dóu repertori @img@, que counten lu image e lu doucumen utilisat en lu article e rùbrica.',
	'texte_admin_tech_02' => 'Mèfi : aquela sauvagarda si pourà estre restaurada SOULAMEN en un sit instalat embé la mema versioun de SPIP. Cau soubretout pas « vuà la basa » en esperant reinstalà la sauvagarda après una messa a jou... Cousultàs la <a href="@spipnet@">la doucumentacioun de SPIP</a>.',
	'texte_restaurer_base' => 'Restaurà lou countengut d’una sauvagarda de la basa',
	'texte_restaurer_sauvegarde' => 'Aquela oupcioun vous permete de restaurà una sauvagarda prechedenta de la
 basa. Per faire acò, cau avé plaçat lou fichié que counten
 la sauvagarda en lou repertori @dossier@.
  Siguès prudent embé aquela founciounalità : <b>li moudificacioun e li perta eventuali noun soun
  reversibli.</b>',
	'texte_sauvegarde' => 'Sauvagardà lou countengut de la basa',
	'texte_sauvegarde_base' => 'Sauvagardà la basa',
	'tout_restaurer' => 'Restaurà touti li taula',
	'tout_sauvegarder' => 'Sauvagardà touti li taula',

	// U
	'une_donnee' => '1 enregistramen'
);

?>
